# WaterTAP
This is the WaterTAP development repository.

WaterTAP is developed as part of the [National Alliance for Water Innovation](https://nawihub.org/) project.

## Build Status

[![Checks](https://github.com/watertap-org/watertap/actions/workflows/checks.yml/badge.svg)](https://github.com/watertap-org/watertap/actions/workflows/checks.yml)
[![Documentation Status](https://readthedocs.org/projects/watertap/badge/?version=latest)](https://watertap.readthedocs.io/en/latest/?badge=latest)
[![codecov](https://codecov.io/gh/watertap-org/watertap/branch/main/graph/badge.svg)](https://codecov.io/gh/watertap-org/watertap)  
[![GitHub contributors](https://img.shields.io/github/contributors/watertap-org/watertap.svg)](https://github.com/watertap-org/watertap/graphs/contributors)  
[![Merged PRs](https://img.shields.io/github/issues-pr-closed-raw/watertap-org/watertap.svg?label=merged+PRs)](https://github.com/watertap-org/watertap/pulls?q=is:pr+is:merged)  
[![Issue stats](http://isitmaintained.com/badge/resolution/watertap-org/watertap.svg)](http://isitmaintained.com/project/watertap-org/watertap)

## Getting started

To quickly install and start using WaterTAP, head over to the [Getting Started](https://watertap.readthedocs.io/en/latest/getting_started/install.html#general-installation) section of the documentation.

## Documentation

The WaterTAP documentation is available online at <https://watertap.readthedocs.io>.
## Developer notes

Refer to the [Getting Started for Developers](https://watertap.readthedocs.io/en/latest/getting_started/install.html#for-watertap-developers) section of the documentation.
